@@ -3,7 +3,6 @@ from .api import Api
 from .filters_schema import FilterField
 from .filters_schema import FilterSchema
 from .filters_schema import ListFilterField
-from .nested.nested_resource_repositories import NestedResourceRepositoryViewSet
 from .resource_repositories.repositories import ResourceRepository
 from .resource_repository_views import ResourceRepositoryDetailView
 from .resource_repository_views import ResourceRepositoryListView
@@ -20,7 +19,6 @@ __all__ = [
     ResourceRepository,
     ResourceRepositoryDetailView,
     ResourceRepositoryListView,
-    NestedResourceRepositoryViewSet,
     ResourceRepositoryViewSet,
     ResourceDetail,
     ResourceList,
